containers Package
==================

:mod:`containers` Package
-------------------------

.. automodule:: numba.containers
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`orderedcontainer` Module
------------------------------

.. automodule:: numba.containers.orderedcontainer
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`register` Module
----------------------

.. automodule:: numba.containers.register
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`typedlist` Module
-----------------------

.. automodule:: numba.containers.typedlist
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`typedtuple` Module
------------------------

.. automodule:: numba.containers.typedtuple
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.containers.tests

